@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require "pathname"
 
 module Bundler
@@ -5,7 +6,7 @@ module Bundler
     TEST_FRAMEWORK_VERSIONS = {
       "rspec" => "3.0",
       "minitest" => "5.0"
-    }
+    }.freeze
 
     attr_reader :options, :gem_name, :thor, :name, :target
 
@@ -27,7 +28,6 @@ module Bundler
       namespaced_path = name.tr("-", "/")
       constant_name = name.gsub(/-[_-]*(?![_-]|$)/) { "::" }.gsub(/([_-]+|(::)|^)(.|$)/) { $2.to_s + $3.upcase }
       constant_array = constant_name.split("::")
-      test_task = options[:test] == "minitest" ? "test" : "spec"
 
       git_user_name = `git config user.name`.chomp
       git_user_email = `git config user.email`.chomp
@@ -42,9 +42,8 @@ module Bundler
         :author           => git_user_name.empty? ? "TODO: Write your name" : git_user_name,
         :email            => git_user_email.empty? ? "TODO: Write your email address" : git_user_email,
         :test             => options[:test],
-        :test_task        => test_task,
         :ext              => options[:ext],
-        :bin              => options[:bin],
+        :exe              => options[:exe],
         :bundler_version  => bundler_dependency_version
       }
       ensure_safe_gem_name(name, constant_array)
@@ -87,6 +86,8 @@ module Bundler
         end
       end
 
+      config[:test_task] = config[:test] == "minitest" ? "test" : "spec"
+
       if ask_and_set(:mit, "Do you want to license your code permissively under the MIT license?",
         "This means that any other developer or company will be legally allowed to use your code " \
         "for free as long as they admit you created it. You can read more about the MIT license " \
@@ -109,7 +110,7 @@ module Bundler
         templates.merge!("CODE_OF_CONDUCT.md.tt" => "CODE_OF_CONDUCT.md")
       end
 
-      templates.merge!("exe/newgem.tt" => "exe/#{name}") if options[:bin]
+      templates.merge!("exe/newgem.tt" => "exe/#{name}") if config[:exe]
 
       if options[:ext]
         templates.merge!(
@@ -135,10 +136,8 @@ module Bundler
         `git add .`
       end
 
-      if options[:edit]
-        # Open gemspec in editor
-        thor.run("#{options["edit"]} \"#{target.join("#{name}.gemspec")}\"")
-      end
+      # Open gemspec in editor
+      open_editor(options["edit"], target.join("#{name}.gemspec")) if options[:edit]
     end
 
   private
@@ -207,5 +206,9 @@ module Bundler
         exit 1
       end
     end
+
+    def open_editor(editor, file)
+      thor.run(%(#{editor} "#{file}"))
+    end
   end
 end
